.. MPL-Data-Cast documentation master file, created by
   sphinx-quickstart on Mon Mar 28 11:20:32 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to the MPL-Data-Cast documentation!
===========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   sec_intro
   sec_cli
   sec_gui



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
